@@ -1,5 +1,6 @@
 /*
- * Copyright (C) 2002 Keisuke Nishida
+ * Copyright (C) 2002-2007 Keisuke Nishida
+ * Copyright (C) 2007 Roger While
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -13,8 +14,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; see the file COPYING.LIB.  If
- * not, write to the Free Software Foundation, Inc., 59 Temple Place,
- * Suite 330, Boston, MA 02111-1307 USA
+ * the Free Software Foundation, 51 Franklin Street, Fifth Floor
+ * Boston, MA 02110-1301 USA
  */
 
 #ifndef COB_CALL_H
@@ -22,13 +23,19 @@
 
 #include <libcob/common.h>
 
-extern void cob_init_call (void);
-extern void cob_set_library_path (const char *path);
+extern void cob_set_cancel (const char *name, void *entry, void *cancel);
 extern void *cob_resolve (const char *name);
+extern void *cob_resolve_1 (const char *name);
 extern const char *cob_resolve_error (void);
 
-extern void *cob_call_resolve (cob_field *f);
+extern void *cob_call_resolve (const cob_field *f);
+extern void *cob_call_resolve_1 (const cob_field *f);
+#ifdef __GNUC__
+extern void cob_call_error (void) __attribute__ ((noreturn));
+#else
 extern void cob_call_error (void);
-extern void cob_cancel (cob_field *f);
+#endif
+extern void cob_cancel (const cob_field *f);
+extern void cob_c_cancel (const char *name);
 
-#endif /* COB_CALL_H_ */
+#endif /* COB_CALL_H */
